==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/common/item/equipment/bauble/CrimsonPendantItem.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.item.equipment.bauble;

import net.minecraft.class_1087;
import net.minecraft.class_1282;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_4722;
import net.minecraft.class_572;
import vazkii.botania.client.core.handler.MiscellaneousModels;
import vazkii.botania.client.render.AccessoryRenderRegistry;
import vazkii.botania.client.render.AccessoryRenderer;
import vazkii.botania.common.handler.EquipmentHandler;
import vazkii.botania.common.item.BotaniaItems;
import vazkii.botania.common.proxy.Proxy;

public class CrimsonPendantItem extends BaubleItem {

	public CrimsonPendantItem(class_1793 props) {
		super(props);
		Proxy.INSTANCE.runOnClient(() -> () -> AccessoryRenderRegistry.register(this, new Renderer()));
	}

	public static boolean onDamage(class_1309 entity, class_1282 source) {
		if (source.method_5534() && !EquipmentHandler.findOrEmpty(BotaniaItems.superLavaPendant, entity).method_7960()) {
			return true;
		}
		return false;
	}

	@Override
	public void onWornTick(class_1799 stack, class_1309 living) {
		if (living.method_5809()) {
			living.method_5646();
		}
	}

	public static class Renderer implements AccessoryRenderer {
		@Override
		public void doRender(class_572<?> bipedModel, class_1799 stack, class_1309 living, class_4587 ms, class_4597 buffers, int light, float limbSwing, float limbSwingAmount, float partialTicks, float ageInTicks, float netHeadYaw, float headPitch) {
			boolean armor = !living.method_6118(class_1304.field_6174).method_7960();
			bipedModel.field_3391.method_22703(ms);
			ms.method_22904(-0.25, 0.5, armor ? 0.05 : 0.12);
			ms.method_22905(0.5F, -0.5F, -0.5F);
			class_1087 model = MiscellaneousModels.INSTANCE.crimsonGem;
			class_4588 buffer = buffers.getBuffer(class_4722.method_24074());
			class_310.method_1551().method_1541().method_3350()
					.method_3367(ms.method_23760(), buffer, null, model, 1, 1, 1, light, class_4608.field_21444);
		}
	}
}

==> Botania-1.20.1-449-FABRIC-20250622.164605-24-sources.jar: vazkii/botania/common/item/equipment/bauble/CrimsonPendantItem.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.item.equipment.bauble;

import net.minecraft.class_1087;
import net.minecraft.class_1282;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_4722;
import net.minecraft.class_572;
import net.minecraft.class_8103;
import vazkii.botania.client.core.handler.MiscellaneousModels;
import vazkii.botania.client.render.AccessoryRenderRegistry;
import vazkii.botania.client.render.AccessoryRenderer;
import vazkii.botania.common.handler.EquipmentHandler;
import vazkii.botania.common.item.BotaniaItems;
import vazkii.botania.common.proxy.Proxy;

public class CrimsonPendantItem extends BaubleItem {

	public CrimsonPendantItem(class_1793 props) {
		super(props);
		Proxy.INSTANCE.runOnClient(() -> () -> AccessoryRenderRegistry.register(this, new Renderer()));
	}

	public static boolean onDamage(class_1309 entity, class_1282 source) {
		return source.method_48789(class_8103.field_42246) &&
				!EquipmentHandler.findOrEmpty(BotaniaItems.superLavaPendant, entity).method_7960();
	}

	@Override
	public void onWornTick(class_1799 stack, class_1309 living) {
		if (living.method_5809()) {
			living.method_5646();
		}
	}

	public static class Renderer implements AccessoryRenderer {
		@Override
		public void doRender(class_572<?> bipedModel, class_1799 stack, class_1309 living, class_4587 ms, class_4597 buffers, int light, float limbSwing, float limbSwingAmount, float partialTicks, float ageInTicks, float netHeadYaw, float headPitch) {
			boolean armor = !living.method_6118(class_1304.field_6174).method_7960();
			bipedModel.field_3391.method_22703(ms);
			ms.method_22904(-0.25, 0.5, armor ? 0.05 : 0.12);
			ms.method_22905(0.5F, -0.5F, -0.5F);
			class_1087 model = MiscellaneousModels.INSTANCE.crimsonGem;
			class_4588 buffer = buffers.getBuffer(class_4722.method_24074());
			class_310.method_1551().method_1541().method_3350()
					.method_3367(ms.method_23760(), buffer, null, model, 1, 1, 1, light, class_4608.field_21444);
		}
	}
}
